# Copyright Amazon.com Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You
# may not use this file except in compliance with the License. A copy of
# the License is located at
#
#     http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is
# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
# ANY KIND, either express or implied. See the License for the specific
# language governing permissions and limitations under the License.

from braket.pennylane_plugin.braket_device import (  # noqa: F401
    BraketAwsQubitDevice,
    BraketLocalQubitDevice,
)
from braket.pennylane_plugin.ops import (  # noqa: F401
    PSWAP,
    CPhaseShift00,
    CPhaseShift01,
    CPhaseShift10,
)

from ._version import __version__  # noqa: F401
